﻿
using CsConfig;
using System;

namespace example
{

	internal class Program
	{
		// Enumeration type used in the configuration
		internal enum Part
		{
			First = 0,
			Second = 2,
			Third = 5,
		};

		// User validator class in the configuration
		internal class UserValidator
		{
			public string CheckMultiplsOf3(object v)
			{
				// If a value id valid, returns null, otherwise a string of an error message
				if (((int)v % 3) == 0) return null;
				else return "It must be a multiple of 3.";
			}
		}

		/// <summary>
		/// Main function
		/// </summary>
		public static void Main(string[] args)
		{
			if (args.Length < 1)
			{
				Environment.Exit(-1);
			}

			// Implementation with the SConfig class
			var config = new SConfig();
			// Add variable programmatically
			config.AddVariable("Def1000", 1000);
			// Add enumeration type programmatically
			config.AddEnumeration(typeof(Part));
			// Add user validator class object
			config.AddValidatorObject(new UserValidator());
			if (!config.Parse(args))
			{
				foreach (var error in config.Errors)
				{
					Console.WriteLine(error);
				}

				Environment.Exit(-1);
			}
			else
			{
				// Show all configuration variables
				foreach (var v in config.Variables)
				{
					Console.WriteLine(v.ToString());
				}

				// Get an expression result
				var v2 = config.GetExpressionResult("Node.Section.Items[\"0\"]");
				Console.WriteLine("Result : " + v2.ToString());
			}
			Environment.Exit(0);
		}
	}
}
